
import { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { useAuth } from '@/contexts/AuthContext';
import { z } from 'zod';
import { zodResolver } from '@hookform/resolvers/zod';
import { useForm } from 'react-hook-form';
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from '@/components/ui/form';
import { Input } from '@/components/ui/input';
import { Button } from '@/components/ui/button';
import { Tabs, TabsContent, TabsList, TabsTrigger } from '@/components/ui/tabs';
import { Mail, User, ArrowRight, Loader2, AlertCircle, CheckCircle2, RefreshCw } from 'lucide-react';
import { toast } from 'sonner';
import Navbar from '@/components/Navbar';
import { Alert, AlertDescription, AlertTitle } from '@/components/ui/alert';

const emailSchema = z.object({
  name: z.string().min(2, { message: "Name must be at least 2 characters" }),
  email: z.string().email({ message: "Please enter a valid email address" }),
  password: z.string().min(6, { message: "Password must be at least 6 characters" }),
  confirmPassword: z.string(),
}).refine((data) => data.password === data.confirmPassword, {
  message: "Passwords do not match",
  path: ["confirmPassword"],
});

const SignUp = () => {
  const navigate = useNavigate();
  const { signUp, resendVerificationEmail } = useAuth();
  const [isLoading, setIsLoading] = useState(false);
  const [isResending, setIsResending] = useState(false);
  const [emailSent, setEmailSent] = useState(false);
  const [userEmail, setUserEmail] = useState('');

  const emailForm = useForm<z.infer<typeof emailSchema>>({
    resolver: zodResolver(emailSchema),
    defaultValues: {
      name: '',
      email: '',
      password: '',
      confirmPassword: '',
    },
  });

  const onSubmitEmail = async (values: z.infer<typeof emailSchema>) => {
    setIsLoading(true);
    try {
      const { error, user, needsEmailConfirmation } = await signUp(
        values.email, 
        values.password,
        { name: values.name }
      );
      
      if (error) {
        if (error.message.includes("User already registered")) {
          toast.error("User already exists", {
            description: "This email is already registered. Please try signing in instead.",
          });
        } else {
          toast.error("Registration failed", {
            description: error.message || "Please try again.",
          });
        }
        return;
      }
      
      setUserEmail(values.email);
      
      if (needsEmailConfirmation) {
        setEmailSent(true);
        toast.success("Verification email sent", {
          description: "Please check your email (including spam folder) to confirm your account.",
        });
      } else {
        toast.success("Account created!", {
          description: "You can now sign in with your credentials.",
        });
        navigate('/sign-in');
      }
    } catch (error) {
      console.error("Sign up error:", error);
      toast.error("Registration failed", {
        description: "Please try again.",
      });
    } finally {
      setIsLoading(false);
    }
  };
  
  const handleResendEmail = async () => {
    if (!userEmail) return;
    
    setIsResending(true);
    try {
      await resendVerificationEmail(userEmail);
    } catch (error) {
      console.error("Resend error:", error);
      toast.error("Failed to resend verification email", {
        description: "Please try again or contact support.",
      });
    } finally {
      setIsResending(false);
    }
  };
  
  if (emailSent) {
    return (
      <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
        <Navbar />
        
        <div className="pt-32 pb-16">
          <div className="container max-w-md mx-auto px-4">
            <div className="glass-panel p-8 animate-fade-up">
              <div className="flex flex-col items-center justify-center gap-4">
                <CheckCircle2 className="h-16 w-16 text-green-500" />
                <h1 className="text-2xl font-bold text-center">Email Verification Sent</h1>
                <p className="text-center text-muted-foreground">
                  We've sent a verification email to <span className="font-medium">{userEmail}</span>.
                  Please check your inbox and spam folder and click the link to verify your account.
                </p>
                
                <Alert className="mt-4 bg-amber-50">
                  <AlertCircle className="h-4 w-4 text-amber-600" />
                  <AlertTitle>Important</AlertTitle>
                  <AlertDescription>
                    You must verify your email before you can sign in. The link in the email will expire after 24 hours.
                  </AlertDescription>
                </Alert>
                
                <div className="mt-2 w-full">
                  <Button 
                    onClick={handleResendEmail} 
                    variant="outline"
                    className="w-full flex items-center justify-center gap-2"
                    disabled={isResending}
                  >
                    {isResending ? (
                      <Loader2 className="h-4 w-4 animate-spin" />
                    ) : (
                      <RefreshCw className="h-4 w-4" />
                    )}
                    {isResending ? "Sending..." : "Resend Verification Email"}
                  </Button>
                </div>
                
                <div className="mt-6 flex flex-col gap-2 w-full">
                  <Button 
                    onClick={() => navigate('/sign-in')} 
                    variant="default"
                    className="w-full"
                  >
                    Go to Sign In
                    <ArrowRight size={16} className="ml-2" />
                  </Button>
                  
                  <Button 
                    onClick={() => {
                      setEmailSent(false);
                      emailForm.reset();
                    }} 
                    variant="outline"
                    className="w-full"
                  >
                    Back to Sign Up
                  </Button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
      <Navbar />
      
      <div className="pt-32 pb-16">
        <div className="container max-w-md mx-auto px-4">
          <div className="glass-panel p-8 animate-fade-up">
            <h1 className="text-2xl font-bold text-center mb-6">Create a FinTap Account</h1>
            
            <Tabs defaultValue="email" className="w-full">
              <TabsList className="grid w-full grid-cols-1 mb-6">
                <TabsTrigger value="email" className="flex items-center gap-2">
                  <Mail size={16} />
                  <span>Email</span>
                </TabsTrigger>
              </TabsList>
              
              <TabsContent value="email">
                <Form {...emailForm}>
                  <form onSubmit={emailForm.handleSubmit(onSubmitEmail)} className="space-y-4">
                    <FormField
                      control={emailForm.control}
                      name="name"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Full Name</FormLabel>
                          <FormControl>
                            <Input placeholder="John Doe" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={emailForm.control}
                      name="email"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Email</FormLabel>
                          <FormControl>
                            <Input placeholder="you@example.com" type="email" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={emailForm.control}
                      name="password"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Password</FormLabel>
                          <FormControl>
                            <Input placeholder="••••••" type="password" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={emailForm.control}
                      name="confirmPassword"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Confirm Password</FormLabel>
                          <FormControl>
                            <Input placeholder="••••••" type="password" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <Alert className="bg-blue-50 my-2">
                      <AlertCircle className="h-4 w-4 text-blue-600" />
                      <AlertTitle className="text-blue-700">Email Verification Required</AlertTitle>
                      <AlertDescription className="text-blue-600 text-sm">
                        After signup, you'll need to verify your email address by clicking the link we'll send you.
                        Please check both your inbox and spam folder.
                      </AlertDescription>
                    </Alert>
                    
                    <Button 
                      type="submit" 
                      className="w-full"
                      disabled={isLoading}
                    >
                      {isLoading ? (
                        <>
                          <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                          Creating Account
                        </>
                      ) : (
                        <>
                          Create Account
                          <ArrowRight size={16} className="ml-2" />
                        </>
                      )}
                    </Button>
                  </form>
                </Form>
              </TabsContent>
            </Tabs>
            
            <div className="mt-6 text-center text-sm text-muted-foreground">
              Already have an account? <Link to="/sign-in" className="text-brand-blue hover:underline">Sign in</Link>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default SignUp;
